# Programmatic API

This project does not expose a programmatic API. Only the command line interface is
stable and documented.

A public programmatic API is being developped in `manifestoo_core
<https://pypi.org/project/manifestsoo-core>` on which this project relies.
